@@ -76,7 +76,7 @@ where
 ///                
 ///                // // Return error if the job is failure, for example:
 ///                // if i >= 3 {
-///                //    return handle.err("Err".to_string());
+///                //    return handle.err("Err");
 ///                // }
 ///            }
 ///            // And return ok if the job successfully completed.
@@ -325,10 +325,10 @@ where
     }
 
     /// Contains the error value for the result.
-    pub fn err(&self, _value: String) {
+    pub fn err(&self, _value: impl Into<String>) {
         let mut result = self.state.mtx.lock().unwrap();
         let (_, ok, error) = &mut *result;
-        *error = Some(_value);
+        *error = Some(_value.into());
         *ok = None;
         self.state.result_ready.store(true, Ordering::Relaxed);
     }
